``pygcam.mcs.schema``
============================

This module defines the object-relational mapping used to interface
with the SQL database (either Sqlite3 or postgresql). It is implemented
using `SqlAlchemy <https://www.sqlalchemy.org>`_.

API
---

.. automodule:: pygcam.mcs.schema
   :members:

